summaryrefslogtreecommitdiffstats
path: root/kdm/kfrontend/themer
diff options
context:
space:
mode:
Diffstat (limited to 'kdm/kfrontend/themer')
-rw-r--r--kdm/kfrontend/themer/kdmitem.cpp18
-rw-r--r--kdm/kfrontend/themer/kdmitem.h10
-rw-r--r--kdm/kfrontend/themer/kdmlabel.cpp10
-rw-r--r--kdm/kfrontend/themer/kdmlabel.h2
-rw-r--r--kdm/kfrontend/themer/kdmlayout.cpp26
-rw-r--r--kdm/kfrontend/themer/kdmlayout.h2
-rw-r--r--kdm/kfrontend/themer/kdmpixmap.cpp8
-rw-r--r--kdm/kfrontend/themer/kdmpixmap.h2
-rw-r--r--kdm/kfrontend/themer/kdmrect.cpp2
-rw-r--r--kdm/kfrontend/themer/kdmthemer.h4
10 files changed, 42 insertions, 42 deletions
diff --git a/kdm/kfrontend/themer/kdmitem.cpp b/kdm/kfrontend/themer/kdmitem.cpp
index eb5283cd9..5f4c42b5a 100644
--- a/kdm/kfrontend/themer/kdmitem.cpp
+++ b/kdm/kfrontend/themer/kdmitem.cpp
@@ -34,7 +34,7 @@
#include <tqframe.h>
#include <tqwidget.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqimage.h>
#include <tqpainter.h>
@@ -280,7 +280,7 @@ KdmItem::setGeometry( const TQRect &newGeometry, bool force )
if (fixedManager && !fixedManager->isEmpty())
fixedManager->update( newGeometry, force );
- // TODO send *selective* tqrepaint signal
+ // TODO send *selective* repaint signal
}
void
@@ -299,7 +299,7 @@ KdmItem::paint( TQPainter *p, const TQRect &rect )
if ((_compositor.isEmpty()) || (!argb_visual_available)) {
// Software blend only (no compositing support)
TQPixmap copy( myWidget->size() );
- kdDebug() << myWidget->tqgeometry() << " " << area << " " << myWidget->size() << endl;
+ kdDebug() << myWidget->geometry() << " " << area << " " << myWidget->size() << endl;
bitBlt( &copy, TQPoint( 0, 0), p->device(), myWidget->geometry(), TQt::CopyROP );
// Lighten it slightly
TQImage lightVersion;
@@ -443,12 +443,12 @@ KdmItem::statusChanged()
// BEGIN protected inheritable
TQSize
-KdmItem::tqsizeHint()
+KdmItem::sizeHint()
{
if (myWidget)
return myWidget->size();
if (myLayoutItem)
- return myLayoutItem->tqsizeHint();
+ return myLayoutItem->sizeHint();
int w = pos.wType == DTpixel ? kAbs( pos.width ) : -1,
h = pos.hType == DTpixel ? kAbs( pos.height ) : -1;
return TQSize( w, h );
@@ -457,7 +457,7 @@ KdmItem::tqsizeHint()
TQRect
KdmItem::placementHint( const TQRect &parentRect )
{
- TQSize hintedSize = tqsizeHint();
+ TQSize hintedSize = sizeHint();
TQSize boxHint;
int x = parentRect.left(),
@@ -474,7 +474,7 @@ KdmItem::placementHint( const TQRect &parentRect )
else {
if (!boxManager)
return parentRect;
- boxHint = boxManager->tqsizeHint();
+ boxHint = boxManager->sizeHint();
}
kdDebug() << timestamp() << " boxHint " << boxHint << endl;
}
@@ -592,7 +592,7 @@ KdmItem::parseAttribute( const TQString &s, int &val, enum DataType &dType )
} else { // int value
dType = DTpixel;
TQString sCopy = s;
- if (sCopy.tqat( 0 ) == '-') {
+ if (sCopy.at( 0 ) == '-') {
sCopy.remove( 0, 1 );
dType = DTnpixel;
}
@@ -616,7 +616,7 @@ KdmItem::parseFont( const TQString &s, TQFont &font )
void
KdmItem::parseColor( const TQString &s, TQColor &color )
{
- if (s.tqat( 0 ) != '#')
+ if (s.at( 0 ) != '#')
return;
bool ok;
TQString sCopy = s;
diff --git a/kdm/kfrontend/themer/kdmlabel.cpp b/kdm/kfrontend/themer/kdmlabel.cpp
index c019851e1..0eab99c30 100644
--- a/kdm/kfrontend/themer/kdmlabel.cpp
+++ b/kdm/kfrontend/themer/kdmlabel.cpp
@@ -116,7 +116,7 @@ KdmLabel::setTextInt( const TQString &txt)
if (cAccel != -1) {
cText.remove('&');
myAccel = new TQAccel(parentWidget());
- myAccel->insertItem(ALT + UNICODE_ACCEL + cText.tqat(cAccel).lower().tqunicode());
+ myAccel->insertItem(ALT + UNICODE_ACCEL + cText.at(cAccel).lower().unicode());
connect(myAccel, TQT_SIGNAL(activated(int)), TQT_SLOT(slotAccel()));
}
}
@@ -138,7 +138,7 @@ KdmLabel::setText( const TQString &txt )
}
TQSize
-KdmLabel::tqsizeHint()
+KdmLabel::sizeHint()
{
// choose the correct label class
struct LabelStruct::LabelClass *l = &label.normal;
@@ -177,8 +177,8 @@ KdmLabel::drawContents( TQPainter *p, const TQRect &/*r*/ )
TQFont f(l->font);
f.setUnderline(true);
p->setFont ( f );
- p->drawText( tarea, AlignLeft | SingleLine, TQString(cText.tqat(cAccel)));
- tarea.rLeft() += fm.width(cText.tqat(cAccel));
+ p->drawText( tarea, AlignLeft | SingleLine, TQString(cText.at(cAccel)));
+ tarea.rLeft() += fm.width(cText.at(cAccel));
p->setFont( l->font );
p->drawText( tarea, AlignLeft | SingleLine, right);
} else {
@@ -268,7 +268,7 @@ KdmLabel::lookupText( const TQString &t )
m['s'] = KThemedGreeter::timedUser;
// xgettext:no-c-format
KGlobal::locale()->setDateFormat( i18n("date format", "%a %d %B") );
- m['c'] = KGlobal::locale()->formatDateTime( TQDateTime::tqcurrentDateTime(), false, false );
+ m['c'] = KGlobal::locale()->formatDateTime( TQDateTime::currentDateTime(), false, false );
return KMacroExpander::expandMacros( text, m );
}
diff --git a/kdm/kfrontend/themer/kdmlabel.h b/kdm/kfrontend/themer/kdmlabel.h
index 33ce1cc00..1ec2f88ec 100644
--- a/kdm/kfrontend/themer/kdmlabel.h
+++ b/kdm/kfrontend/themer/kdmlabel.h
@@ -42,7 +42,7 @@ public:
protected:
// reimplemented; returns the minimum size of rendered text
- virtual TQSize tqsizeHint();
+ virtual TQSize sizeHint();
// draw the label
virtual void drawContents( TQPainter *p, const TQRect &r );
diff --git a/kdm/kfrontend/themer/kdmlayout.cpp b/kdm/kfrontend/themer/kdmlayout.cpp
index 83a4ea377..093d450fc 100644
--- a/kdm/kfrontend/themer/kdmlayout.cpp
+++ b/kdm/kfrontend/themer/kdmlayout.cpp
@@ -74,7 +74,7 @@ KdmLayoutBox::update( const TQRect &parentGeometry, bool force )
// Check if box size was computed. If not compute it
// TODO check if this prevents updating changing items
// if (!hintedSize.isValid())
-// tqsizeHint();
+// sizeHint();
// kdDebug() << this << " hintedSize " << hintedSize << endl;
@@ -114,30 +114,30 @@ KdmLayoutBox::update( const TQRect &parentGeometry, bool force )
if ((*it)->isExplicitlyHidden())
continue;
- TQRect temp = childrenRect, tqitemRect;
+ TQRect temp = childrenRect, itemRect;
if (box.isVertical) {
temp.setHeight( 0 );
- tqitemRect = (*it)->placementHint( temp );
- temp.setHeight( tqitemRect.height() );
- childrenRect.setTop( childrenRect.top() + tqitemRect.size().height() + box.spacing );
+ itemRect = (*it)->placementHint( temp );
+ temp.setHeight( itemRect.height() );
+ childrenRect.setTop( childrenRect.top() + itemRect.size().height() + box.spacing );
} else {
temp.setWidth( 0 );
- tqitemRect = (*it)->placementHint( temp );
- kdDebug() << this << " placementHint " << *it << " " << temp << " " << tqitemRect << endl;
- temp.setWidth( tqitemRect.width() );
- childrenRect.setLeft( childrenRect.left() + tqitemRect.size().width() + box.spacing );
+ itemRect = (*it)->placementHint( temp );
+ kdDebug() << this << " placementHint " << *it << " " << temp << " " << itemRect << endl;
+ temp.setWidth( itemRect.width() );
+ childrenRect.setLeft( childrenRect.left() + itemRect.size().width() + box.spacing );
kdDebug() << timestamp() << " childrenRect after " << *it << " " << childrenRect << endl;
}
- tqitemRect = (*it)->placementHint( temp );
- kdDebug() << this << " placementHint2 " << *it << " " << temp << " " << tqitemRect << endl;
- (*it)->setGeometry( tqitemRect, force );
+ itemRect = (*it)->placementHint( temp );
+ kdDebug() << this << " placementHint2 " << *it << " " << temp << " " << itemRect << endl;
+ (*it)->setGeometry( itemRect, force );
}
}
}
//FIXME truly experimental (is so close to greeter_geometry.c)
TQSize
-KdmLayoutBox::tqsizeHint()
+KdmLayoutBox::sizeHint()
{
// Sum up area taken by children
int w = 0, h = 0;
diff --git a/kdm/kfrontend/themer/kdmlayout.h b/kdm/kfrontend/themer/kdmlayout.h
index 69b515d67..4c73e9a1b 100644
--- a/kdm/kfrontend/themer/kdmlayout.h
+++ b/kdm/kfrontend/themer/kdmlayout.h
@@ -80,7 +80,7 @@ public:
// Computes the size hint of the box, telling which is the
// smallest size inside which boxed items will fit
- TQSize tqsizeHint();
+ TQSize sizeHint();
private:
struct {
diff --git a/kdm/kfrontend/themer/kdmpixmap.cpp b/kdm/kfrontend/themer/kdmpixmap.cpp
index 6bb1fc57d..8020bd1e1 100644
--- a/kdm/kfrontend/themer/kdmpixmap.cpp
+++ b/kdm/kfrontend/themer/kdmpixmap.cpp
@@ -107,7 +107,7 @@ KdmPixmap::KdmPixmap( KdmItem *parent, const TQDomNode &node, const char *name )
}
TQSize
-KdmPixmap::tqsizeHint()
+KdmPixmap::sizeHint()
{
// choose the correct pixmap class
PixmapStruct::PixmapClass * pClass = &pixmap.normal;
@@ -118,7 +118,7 @@ KdmPixmap::tqsizeHint()
// use the pixmap size as the size hint
if (!pClass->pixmap.isNull())
return pClass->pixmap.size();
- return KdmItem::tqsizeHint();
+ return KdmItem::sizeHint();
}
void
@@ -138,7 +138,7 @@ KdmPixmap::fullPath( const TQString &fileName)
return TQString::null;
TQString fullName = fileName;
- if (fullName.tqat( 0 ) != '/')
+ if (fullName.at( 0 ) != '/')
fullName = baseDir() + "/" + fileName;
return fullName;
}
@@ -177,7 +177,7 @@ KdmPixmap::loadPixmap( PixmapStruct::PixmapClass *pClass )
TQString ext = fullpath.right(fullpath.length() - index);
fullpath = fullpath.left(index);
kdDebug() << timestamp() << " ext " << ext << " " << fullpath << endl;
- TQString testpath = TQString("-%1x%2").tqarg(area.width()).arg(area.height()) + ext;
+ TQString testpath = TQString("-%1x%2").arg(area.width()).arg(area.height()) + ext;
kdDebug() << timestamp() << " testing for " << fullpath + testpath << endl;
if (KStandardDirs::exists(fullpath + testpath))
pClass->pixmap.load(fullpath + testpath);
diff --git a/kdm/kfrontend/themer/kdmpixmap.h b/kdm/kfrontend/themer/kdmpixmap.h
index d49394bc9..a12c9fea4 100644
--- a/kdm/kfrontend/themer/kdmpixmap.h
+++ b/kdm/kfrontend/themer/kdmpixmap.h
@@ -42,7 +42,7 @@ public:
protected:
// reimplemented; returns the size of loaded pixmap
- virtual TQSize tqsizeHint();
+ virtual TQSize sizeHint();
// draw the pixmap
virtual void drawContents( TQPainter *p, const TQRect &r );
diff --git a/kdm/kfrontend/themer/kdmrect.cpp b/kdm/kfrontend/themer/kdmrect.cpp
index 1db128da0..7805ba846 100644
--- a/kdm/kfrontend/themer/kdmrect.cpp
+++ b/kdm/kfrontend/themer/kdmrect.cpp
@@ -29,7 +29,7 @@
#include <tqimage.h>
#include <tqpainter.h>
#include <tqwidget.h>
-#include <tqlayout.h>
+#include <layout.h>
extern bool argb_visual_available;
diff --git a/kdm/kfrontend/themer/kdmthemer.h b/kdm/kfrontend/themer/kdmthemer.h
index e6e5efdb4..f9a0b1b6f 100644
--- a/kdm/kfrontend/themer/kdmthemer.h
+++ b/kdm/kfrontend/themer/kdmthemer.h
@@ -61,9 +61,9 @@ public:
bool isOK() { return rootItem != 0; }
/*
- * Gives a tqsizeHint to the widget (parent size)
+ * Gives a sizeHint to the widget (parent size)
*/
- //TQSize tqsizeHint() const{ return parentWidget()->size(); }
+ //TQSize sizeHint() const{ return parentWidget()->size(); }
/*
* Takes a shot of the current widget
diff --git a/kdm/kfrontend/themer/kdmitem.h b/kdm/kfrontend/themer/kdmitem.h
index ca6bd3435..230ed71c4 100644
--- a/kdm/kfrontend/themer/kdmitem.h
+++ b/kdm/kfrontend/themer/kdmitem.h
@@ -96,7 +96,7 @@ public:
/**
* Fixup the geometry of an item and its children (even if fixed
- * or boxed ones). Note that this will generate tqrepaint signals
+ * or boxed ones). Note that this will generate repaint signals
* when needed. The default implementation should fit all needs.
*/
virtual void setGeometry( const TQRect &newGeometry, bool force );
@@ -109,7 +109,7 @@ public:
void paint( TQPainter *painter, const TQRect &boundaries );
/**
- * Update representation of contents and tqrepaint.
+ * Update representation of contents and repaint.
*/
virtual void update();
@@ -120,7 +120,7 @@ public:
void mouseEvent( int x, int y, bool pressed = false, bool released = false );
/**
* Similar to tqsizeHint(..), this returns the area of the item
* given the @p parentGeometry. The default implementation
* takes into account geometric constraints and layoutings.
* @param parentGeometry the geometry of the caller item or a
@@ -181,7 +181,7 @@ protected:
* @return (-1,-1) if no size can be determined (so it should
* default to parent's size).
*/
- virtual TQSize tqsizeHint();
+ virtual TQSize sizeHint();
/**
* Low level graphical function to paint the item.
@@ -195,7 +195,7 @@ protected:
/**
* Called when item changes its 'state' variable. This must
- * handle item's tqrepaint.
+ * handle item's repaint.
*/
virtual void statusChanged();
@@ -120,7 +120,7 @@ public:
void mouseEvent( int x, int y, bool pressed = false, bool released = false );
/**
- * Similar to tqsizeHint(..), this returns the area of the item
+ * Similar to sizeHint(..), this returns the area of the item
* given the @p parentGeometry. The default implementation
* takes into account geometric constraints and layoutings.